@@ -94,7 +94,7 @@ psfmi_lr_bw <- function(data, nimp, impvar, Outcome, P, p.crit, method, keep.P)
     }
 
     # D1 and D2 pooling methods
-    if(method=="D1" | method == "D2" | method=="D3") {
+    if(method=="D1" | method == "D2" | method=="D3" | method=="D4") {
 
       pool.p.val <-
         matrix(0, length(P), 2)
@@ -121,12 +121,50 @@ psfmi_lr_bw <- function(data, nimp, impvar, Outcome, P, p.crit, method, keep.P)
           form0 <-
             as.formula(paste(Y, paste(c(cov.nam0), collapse = "+")))
         }
-
+        if(method=="D4"){
+          data <-
+            filter(data, data[impvar] <= nimp)
+          imp_list <-
+            data %>% group_split(data[, impvar], .keep = FALSE) %>%
+            mitools::imputationList(imp_list)
+          
+          fit0 <-
+            with(data=imp_list, expr= glm(as.formula(paste(Y,
+                       paste(cov.nam0, collapse = "+"))), family = binomial))
+          fit1 <-
+            with(data=imp_list, expr= glm(as.formula(paste(Y,
+                       paste(P, collapse = "+"))), family = binomial))
+          
+          out.res1 <-
+            summary(pool(fit1))
+          OR <-
+            exp(out.res1$estimate)
+          lower.EXP <-
+            exp(out.res1$estimate - (qt(0.975, out.res1$df)*out.res1$std.error))
+          upper.EXP <-
+            exp(out.res1$estimate + (qt(0.975, out.res1$df)*out.res1$std.error))
+          model.res1 <-
+            data.frame(cbind(out.res1, OR, lower.EXP, upper.EXP))
+          RR.model[[k]] <-
+            model.res1
+          names(RR.model)[[k]] <-
+            paste("Step", k)
+          
+          res_D4 <- 
+            pool_D4(data=data, fm0=form0, fm1=form1, nimp=nimp,
+                            impvar=impvar, robust=TRUE, model_type="binomial")
+          pvalue <-
+            res_D4$pval
+          fstat <-
+            res_D4$F
+          pool.p.val[j, ] <-
+            c(pvalue, fstat)
+        }
         if(method=="D3"){
           data <-
             filter(data, data[impvar] <= nimp)
           imp_list <-
-            data %>% group_split(data[, impvar], keep = FALSE) %>%
+            data %>% group_split(data[, impvar], .keep = FALSE) %>%
             mitools::imputationList(imp_list)
 
           fit0 <-
@@ -407,6 +445,18 @@ psfmi_lr_bw <- function(data, nimp, impvar, Outcome, P, p.crit, method, keep.P)
       multiparm_step[k+1]
     fm_step_final <-
       fm_step_total[k+1]
+    if(p.crit==1) {
+      Y_initial <-
+        c(paste(Outcome, paste("~")))
+      formula_initial <-
+        as.formula(paste(Y_initial, paste(P_orig, collapse = "+")))
+      fm_step_final <- 
+        formula_initial
+      RR_model_final <-
+        RR_model_step[k]
+      multiparm_final <-
+        multiparm_step[k]
+    }
   }
   if(!is_empty(P) & p.crit !=1){
     RR_model_step <-
@@ -443,4 +493,4 @@ psfmi_lr_bw <- function(data, nimp, impvar, Outcome, P, p.crit, method, keep.P)
          predictors_final = predictors_final,
          predictors_initial = P_orig, keep.predictors = keep.P)
   return(bw)
-}
+}
\ No newline at end of file
